searchData={"items":[{"type":"module","title":"ComputeRated","doc":"A leaky bucket rate limiter optimized for compute time limits.\n\nThis module provides a rate limiter that tracks compute time usage and allows\nchecking and waiting for available capacity. It's based on the leaky bucket\nalgorithm where compute time gradually drains from the bucket over time.","ref":"ComputeRated.html"},{"type":"function","title":"ComputeRated.add_compute_time/4","doc":"Add compute time to the bucket.","ref":"ComputeRated.html#add_compute_time/4"},{"type":"function","title":"Arguments: - ComputeRated.add_compute_time/4","doc":"- `id` (Erlang term()) name of the bucket\n- `scale` (Integer) time in ms over which the bucket drains\n- `limit` (Integer) the max amount of compute time the bucket can hold\n- `amount` (Integer) the amount of compute time to add","ref":"ComputeRated.html#add_compute_time/4-arguments"},{"type":"function","title":"Examples - ComputeRated.add_compute_time/4","doc":"# Add 100 units of compute time to a bucket\n    iex> ComputeRated.add_compute_time(\"my-bucket\", 60_000, 1000, 100)\n    {:ok, 100, 900}","ref":"ComputeRated.html#add_compute_time/4-examples"},{"type":"function","title":"ComputeRated.check_rate/4","doc":"Check if adding the specified amount of compute time would exceed the bucket's limit.","ref":"ComputeRated.html#check_rate/4"},{"type":"function","title":"Arguments: - ComputeRated.check_rate/4","doc":"- `id` (Erlang term()) name of the bucket\n- `scale` (Integer) time in ms over which the bucket drains\n- `limit` (Integer) the max amount of compute time the bucket can hold\n- `amount` (Integer) the amount of compute time to check for","ref":"ComputeRated.html#check_rate/4-arguments"},{"type":"function","title":"Examples - ComputeRated.check_rate/4","doc":"# Check if adding 100 units of compute time would exceed a bucket with limit 1000\n    iex> ComputeRated.check_rate(\"my-bucket\", 60_000, 1000, 100)\n    {:ok, 100, 900}\n\n    # When it would exceed the limit\n    iex> ComputeRated.check_rate(\"my-bucket\", 60_000, 1000, 1100)\n    {:error, 1000, 0}","ref":"ComputeRated.html#check_rate/4-examples"},{"type":"function","title":"ComputeRated.delete_bucket/1","doc":"Delete bucket to reset the compute time counter.","ref":"ComputeRated.html#delete_bucket/1"},{"type":"function","title":"Arguments: - ComputeRated.delete_bucket/1","doc":"- `id` (String) name of the bucket","ref":"ComputeRated.html#delete_bucket/1-arguments"},{"type":"function","title":"Example - Reset counter for my-bucket - ComputeRated.delete_bucket/1","doc":"iex> ComputeRated.delete_bucket(\"my-bucket\")\n    :ok","ref":"ComputeRated.html#delete_bucket/1-example-reset-counter-for-my-bucket"},{"type":"function","title":"ComputeRated.start_link/2","doc":"Starts the ComputeRated server.","ref":"ComputeRated.html#start_link/2"},{"type":"function","title":"ComputeRated.stop/1","doc":"Stop the rate limit counter server.","ref":"ComputeRated.html#stop/1"},{"type":"function","title":"ComputeRated.wait_for_capacity/5","doc":"Sleep until there's enough capacity in the bucket for the specified amount,\nor optionally until the bucket is fully depleted.","ref":"ComputeRated.html#wait_for_capacity/5"},{"type":"function","title":"Arguments: - ComputeRated.wait_for_capacity/5","doc":"- `id` (Erlang term()) name of the bucket\n- `scale` (Integer) time in ms over which the bucket drains\n- `limit` (Integer) the max amount of compute time the bucket can hold\n- `estimated_cost` (Integer, optional) the estimated amount that will be added after waiting\n- `wait_for_full_depletion` (Boolean, optional) if true, waits until bucket is empty","ref":"ComputeRated.html#wait_for_capacity/5-arguments"},{"type":"function","title":"Examples - ComputeRated.wait_for_capacity/5","doc":"# Wait until there's enough capacity for 100 units\n    iex> ComputeRated.wait_for_capacity(\"my-bucket\", 60_000, 1000, 100)\n    :ok\n\n    # Wait until the bucket is completely empty\n    iex> ComputeRated.wait_for_capacity(\"my-bucket\", 60_000, 1000, nil, true)\n    :ok","ref":"ComputeRated.html#wait_for_capacity/5-examples"},{"type":"extras","title":"ComputeRated","doc":"# ComputeRated\n\nA leaky bucket rate limiter optimized for compute time limits.\n\nComputeRated allows you to:\n- Check if adding compute time would exceed a bucket's capacity\n- Add compute time to a bucket\n- Wait until a bucket has sufficient capacity or is fully depleted\n- Track compute time usage over specified time windows","ref":"readme.html"},{"type":"extras","title":"Installation - ComputeRated","doc":"The package can be installed by adding `compute_rated` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:compute_rated, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ComputeRated","doc":"```elixir\n# Check if adding 100 units of compute time would exceed a bucket's capacity\n{:ok, current, remaining} = ComputeRated.check_rate(\"my-bucket\", 60_000, 1000, 100)\n\n# Add 100 units of compute time to a bucket\n{:ok, current, remaining} = ComputeRated.add_compute_time(\"my-bucket\", 60_000, 1000, 100)\n\n# Wait until there's enough capacity for an estimated 200 units\n:ok = ComputeRated.wait_for_capacity(\"my-bucket\", 60_000, 1000, 200)\n\n# Wait until the bucket is completely empty\n:ok = ComputeRated.wait_for_capacity(\"my-bucket\", 60_000, 1000, nil, true)\n\n# Delete a bucket\n:ok = ComputeRated.delete_bucket(\"my-bucket\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Configuration - ComputeRated","doc":"ComputeRated can be configured in your `config.exs`:\n\n```elixir\nconfig :compute_rated,\n  timeout: 90_000_000,       # bucket maximum lifetime (25 hours)\n  cleanup_rate: 60_000,      # cleanup every minute\n  ets_table_name: :compute_rated_buckets,  # the registered name of the ETS table\n  persistent: false          # whether to persist the buckets to disk\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Third-Party Attributions - ComputeRated","doc":"This project includes modified code from ExRated by Glenn Rempe (https://github.com/grempe/ex_rated).\n  For full attribution and license information, please see the ATTRIBUTION file.","ref":"readme.html#third-party-attributions"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}